Color

Enum Color 

#[repr(u8)]
pub enum Color { White = 0, Black = 1, }
Represents the color of a player, piece, square, etc. within a chess board.

In Western chess, White traditionally moves first, and therefore Color defaults to Color::White.

Variants



White = 0



Black = 1

Implementations

Source

impl Color

pub const COUNT: usize = 2usize

Number of color variants.

pub const fn all() -> [Color; 2]

An array of both colors, starting with White.

pub fn iter() -> impl Iterator<Item = Color>

An iterator over both colors, starting with White.

pub fn from_bits(bits: u8) -> Result<Color, Error>

Creates a new Color from a set of bits.

bits must be [0,1].

Panics

If bits is greater than 1.

Example
let white = Color::from_bits(0);
assert!(white.is_ok());
assert_eq!(white.unwrap(), Color::White);

let err = Color::from_bits(42);
assert!(err.is_err());
pub const fn from_bits_unchecked(bits: u8) -> Color

Creates a new Color from a set of bits, ignoring safety checks.

bits must be [0,1].

Panics

If bits is greater than 1 and debug assertions are enabled.

Example
let white = Color::from_bits(0);
assert!(white.is_ok());
assert_eq!(white.unwrap(), Color::White);

let err = Color::from_bits(42);
assert!(err.is_err());
pub const fn from_bool(color: bool) -> Color

Creates a new Color from a bool, where false = White.

Example
let white = Color::from_bool(false);
assert_eq!(white, Color::White);

let black = Color::from_bool(true);
assert_eq!(black, Color::Black);
pub const fn is_white(&self) -> bool

Returns true if this Color is White.

pub const fn is_black(&self) -> bool

Returns true if this Color is Black.

pub const fn negation_multiplier(&self) -> i8

Returns a multiplier for negating numbers relative to this color.

Example
assert_eq!(Color::White.negation_multiplier(), 1);
assert_eq!(Color::Black.negation_multiplier(), -1);
pub const fn opponent(&self) -> Color

Returns this Color’s opposite / inverse / enemy.

Example
assert_eq!(Color::White.opponent(), Color::Black);
assert_eq!(Color::Black.opponent(), Color::White);
pub const fn index(&self) -> usize

Returns this Color as a usize.

Will be 0 for White, 1 for Black.

Useful for indexing into lists.

Example
assert_eq!(Color::White.index(), 0);
assert_eq!(Color::Black.index(), 1);
pub const fn bits(&self) -> u8

Returns this Color as a u8.

Will be 0 for White, 1 for Black.

Useful for bit twiddling.

Example
assert_eq!(Color::White.bits(), 0);
assert_eq!(Color::Black.bits(), 1);
pub fn from_uci(color: char) -> Result<Color, Error>

Creates a Color from a char, according to the Universal Chess Interface notation.

Example
let white = Color::from_uci('w');
assert!(white.is_ok());
assert_eq!(white.unwrap(), Color::White);

let err = Color::from_uci('x');
assert!(err.is_err());
pub const fn from_case(c: char) -> Color

Creates a Color based on the ASCII case of the provided character, with uppercase being White and lowercase being Black.

Note this is intended to follow the Universal Chess Interface notation, but can be used in odd ways, such as trying to find the color of the char 'z' (Black).

Example
assert_eq!(Color::from_case('k'), Color::Black);
pub const fn to_uci(&self) -> char

Converts this Color to a char, according to the Universal Chess Interface notation.

Example
assert_eq!(Color::White.to_uci(), 'w');
pub const fn as_str(&self) -> &'static str

Converts this Color to a str, according to the Universal Chess Interface notation.

Example
assert_eq!(Color::White.as_str(), "w");
pub const fn name(&self) -> &'static str

Fetches a human-readable name for this Color.

Example
let white = Color::White;
assert_eq!(white.name(), "white");